@@ -14,7 +14,7 @@
 /**
  * The basic handler for data objects in a Kolab storage folder.
  *
- * Copyright 2011-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -268,14 +268,41 @@ implements Horde_Kolab_Storage_Data, Horde_Kolab_Storage_Data_Query
         } else {
             $writer = new Horde_Kolab_Storage_Object_Writer_Raw();
         }
+
+        // Mark removed attachments as to-be-deleted.
+        $oldObject = $this->getObject($object['uid']);
+        $oldAttachments = isset($oldObject['inline-attachments'])
+            ? $oldObject['inline-attachments']
+            : array();
+        if ($oldObject['picture']) {
+            $oldAttachments[] = $oldObject['picture'];
+        }
+        $newAttachments = isset($object['inline-attachments'])
+            ? $object['inline-attachments']
+            : array();
+        if (isset($object['picture'])) {
+            $newAttachments[] = $object['picture'];
+        }
+        $attachments = isset($object['_attachments'])
+            ? $object['_attachments']
+            : array();
+        foreach (array_diff($oldAttachments, $newAttachments) as $attachment) {
+            $attachments[$attachment] = null;
+        }
+        $object['_attachments'] = $attachments;
+
         if (!$object instanceOf Horde_Kolab_Storage_Object) {
             $object_array = $object;
-            $object = $this->getObject($object_array['uid']);
+            $object = $oldObject;
             $object->setData($object_array);
         }
+
         $object->setDriver($this->_driver);
         $result = $object->save($writer);
 
+        // Filter out removed attachments so that they won't be synchronized.
+        $object['_attachments'] = array_filter($object['_attachments']);
+
         if ($result === true) {
             $params = array();
         } else {
@@ -415,15 +442,21 @@ implements Horde_Kolab_Storage_Data, Horde_Kolab_Storage_Data_Query
     }
 
     /**
-     * Return the specified attachment.
+     * Returns the specified attachment.
      *
-     * @param string $attachment_id The attachment id.
+     * @param string $object_id      The object id. @since Kolab_Storage 2.1.0
+     * @param string $attachment_id  The attachment id.
      *
      * @return resource An open stream to the attachment data.
      */
-    public function getAttachment($attachment_id)
+    public function getAttachment($object_id, $attachment_id)
     {
-        //@todo: implement
+        foreach ($this->fetch($this->getStamp()->ids()) as $object) {
+            if ($object->getBackendId() == $object_id &&
+                isset($object['_attachments'][$attachment_id])) {
+                return $object['_attachments'][$attachment_id]['content'];
+            }
+        }
     }
 
     /**
