@@ -14,7 +14,7 @@
 /**
  * An cclient based Kolab storage driver.
  *
- * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -663,7 +663,7 @@ extends Horde_Kolab_Storage_Driver_Base
      * @param array  $uid    The message UID.
      * @param array  $id     The mime part ID.
      *
-     * @return resource|string The body part, as a stream resource or string.
+     * @return resource  The body part, as a stream resource.
      */
     public function fetchBodypart($folder, $uid, $id)
     {
@@ -685,7 +685,7 @@ extends Horde_Kolab_Storage_Driver_Base
                 )
             );
         }
-        return $result;
+        return Horde_Stream_Wrapper_String::getStream($result);
     }
 
     /**
