@@ -14,7 +14,7 @@
 /**
  * The IMAP driver class for accessing Kolab storage.
  *
- * Copyright 2009-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -124,7 +124,6 @@ extends Horde_Kolab_Storage_Driver_Base
     public function hasAclSupport()
     {
         try {
-            $this->getBackend()->login();
             return $this->getBackend()->queryCapability('ACL');
         } catch (Horde_Imap_Client_Exception_ServerResponse $e) {
             throw new Horde_Kolab_Storage_Exception($e->details);
@@ -225,19 +224,19 @@ extends Horde_Kolab_Storage_Driver_Base
      */
     public function listAnnotation($annotation)
     {
+        $data = array();
+
         try {
-            $result = $this->getBackend()->getMetadata('*', $annotation);
+            foreach ($this->listFolders() as $val) {
+                if (strlen($res = $this->getAnnotation((string)$val, $annotation))) {
+                    $data[(string)$val] = $res;
+                }
+            }
         } catch (Horde_Imap_Client_Exception_ServerResponse $e) {
             throw new Horde_Kolab_Storage_Exception($e->details);
         } catch (Horde_Imap_Client_Exception $e) {
             throw new Horde_Kolab_Storage_Exception($e);
         }
-        $data = array();
-        foreach ($result as $folder => $annotations) {
-            if (isset($annotations[$annotation])) {
-                $data[$folder] = $annotations[$annotation];
-            }
-        }
 
         return $data;
     }
@@ -253,7 +252,6 @@ extends Horde_Kolab_Storage_Driver_Base
     public function getAnnotation($folder, $annotation)
     {
         try {
-            $this->getBackend()->login();
             $result = $this->getBackend()->getMetadata($folder, $annotation);
         } catch (Exception $e) {
             return '';
@@ -273,7 +271,6 @@ extends Horde_Kolab_Storage_Driver_Base
     public function setAnnotation($folder, $annotation, $value)
     {
         try {
-            $this->getBackend()->login();
             return $this->getBackend()->setMetadata(
                 $folder, array($annotation => $value)
             );
@@ -511,12 +508,13 @@ extends Horde_Kolab_Storage_Driver_Base
      * @param array  $uid                 The message UID.
      * @param array  $id                  The mime part ID.
      *
-     * @return resource|string The body part, as a stream resource or string.
+     * @return resource  The body part, as a stream resource.
      */
     public function fetchBodypart($folder, $uid, $id)
     {
         $query = new Horde_Imap_Client_Fetch_Query();
-        $query->bodyPart($id);
+        $query->structure();
+        $query->bodyPart($id, array('decode' => true));
 
         try {
             $ret = $this->getBackend()->fetch(
@@ -524,8 +522,15 @@ extends Horde_Kolab_Storage_Driver_Base
                 $query,
                 array('ids' => new Horde_Imap_Client_Ids($uid))
             );
-
-            return $ret[$uid]->getBodyPart($id, true);
+            $part = $ret[$uid]->getStructure()->getPart($id);
+            $part->setContents(
+                $ret[$uid]->getBodyPart($id, true),
+                array(
+                    'encoding' => $ret[$uid]->getBodyPartDecode($id),
+                    'usestream' => true
+                )
+            );
+            return $part->getContents(array('stream' => true));
         } catch (Horde_Imap_Client_Exception_ServerResponse $e) {
             throw new Horde_Kolab_Storage_Exception($e->details);
         } catch (Horde_Imap_Client_Exception $e) {
