@@ -14,7 +14,7 @@
 /**
  * Represents a single Kolab object.
  *
- * Copyright 2011-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -149,7 +149,10 @@ class Horde_Kolab_Storage_Object implements ArrayAccess, Serializable
         return $this->_folder;
     }
 
-    private function _getBackendId()
+    /**
+     * @since Horde_Kolab_Storage 2.1.0
+     */
+    public function getBackendId()
     {
         if (empty($this->_backend_id)) {
             throw new Horde_Kolab_Storage_Object_Exception(
@@ -189,7 +192,7 @@ class Horde_Kolab_Storage_Object implements ArrayAccess, Serializable
         if ($this->_headers === null) {
             $this->_headers = $this->_getDriver()->fetchHeaders(
                 $this->_getFolder(),
-                $this->_getBackendId()
+                $this->getBackendId()
             );
         }
         return $this->_headers;
@@ -215,7 +218,7 @@ class Horde_Kolab_Storage_Object implements ArrayAccess, Serializable
         if ($this->_content === null) {
             $this->_content = $this->_getDriver()->fetchBodypart(
                 $this->_getFolder(),
-                $this->_getBackendId(),
+                $this->getBackendId(),
                 $this->_getMimePartId()
             );
         }
@@ -313,6 +316,15 @@ class Horde_Kolab_Storage_Object implements ArrayAccess, Serializable
         $this->_type = $type;
         $envelope = $this->createEnvelope();
         $envelope->addPart($this->createFreshKolabPart($data->save($this)));
+        if (isset($this['_attachments'])) {
+            foreach ($this['_attachments'] as $name => $attachment) {
+                $part = new Horde_Mime_Part();
+                $part->setType($attachment['type']);
+                $part->setContents($attachment['content']);
+                $part->setName($name);
+                $envelope->addPart($part);
+            }
+        }
         $envelope->buildMimeIds();
         $this->_mime_part_id = Horde_Kolab_Storage_Object_MimeType::matchMimePartToObjectType(
             $envelope, $this->getType()
@@ -321,48 +333,37 @@ class Horde_Kolab_Storage_Object implements ArrayAccess, Serializable
     }
 
     /**
-     * Load the object from the backend.
+     * Loads the object from the backend.
      *
-     * @param string $backend_id The object ID within the backend.
-     * @param Horde_Kolab_Storage_Folder  $folder  The folder to retrieve the
-     *                                             data object from.
-     * @param Horde_Kolab_Storage_Object_Writer $data The data parser.
-     * @param Horde_Mime_Part $structure The MIME message structure of the object.
+     * @param string $backend_id                       The object ID within the
+     *                                                 backend.
+     * @param Horde_Kolab_Storage_Folder $folder       The folder to retrieve
+     *                                                 the data object from.
+     * @param Horde_Kolab_Storage_Object_Writer $data  The data parser.
+     * @param Horde_Mime_Part $structure               The MIME message
+     *                                                 structure of the object.
      */
     public function load($backend_id,
                          Horde_Kolab_Storage_Folder $folder,
                          Horde_Kolab_Storage_Object_Writer $data,
-                         $structure = null)
+                         Horde_Mime_Part $structure = null)
     {
         $this->_folder = $folder->getPath();
         $this->_backend_id = $backend_id;
 
-        if (!$structure instanceOf Horde_Mime_Part) {
-            throw new Horde_Kolab_Storage_Data_Exception(
-                sprintf(
-                    'The provided data is not of type Horde_Mime_Part but %s instead!',
-                    get_class($structure)
-                )
-            );
-        }
-
         $result = Horde_Kolab_Storage_Object_MimeType::matchMimePartToFolderType(
             $structure, $folder->getType()
         );
 
-        /**
-         * No object content matching the folder type: Try fetching the header
-         * and look for a Kolab type deviating from the folder type.
-         */
-        if ($result === false | $result[0] === false) {
+        /* No object content matching the folder type: Try fetching the header
+         * and look for a Kolab type deviating from the folder type. */
+        if ($result === false || $result[0] === false) {
             $result = Horde_Kolab_Storage_Object_MimeType::matchMimePartToHeaderType(
                 $structure,
                 $this->getHeaders()
             );
-            /**
-             * Seems to have no Kolab data part: mark invalid.
-             */
-            if ($result === false | $result[0] === false) {
+            /* Seems to have no Kolab data part: mark invalid. */
+            if ($result === false || $result[0] === false) {
                 $this->_type = self::TYPE_INVALID;
                 $this->addParseError(self::ERROR_MISSING_KOLAB_PART);
                 return;
@@ -380,6 +381,21 @@ class Horde_Kolab_Storage_Object implements ArrayAccess, Serializable
         $result = $data->load($mime_part->getContents(array('stream' => true)), $this);
         if ($result instanceOf Exception) {
             $this->addParseError(self::ERROR_INVALID_KOLAB_PART, $result->getMessage());
+        } else {
+            foreach ($structure->getParts() as $part) {
+                if ($part->getMimeId() == $this->_mime_part_id ||
+                    !$part->getName()) {
+                    continue;
+                }
+                $this->_data['_attachments'][$part->getName()] = array(
+                    'type' => $part->getType(),
+                    'content' => $this->_getDriver()->fetchBodypart(
+                            $this->_getFolder(),
+                            $this->getBackendId(),
+                            $part->getMimeId()
+                    )
+                );
+            }
         }
 
         $this->_structure = $structure;
@@ -397,8 +413,8 @@ class Horde_Kolab_Storage_Object implements ArrayAccess, Serializable
      */
     public function save(Horde_Kolab_Storage_Object_Writer $data)
     {
-        list($headers, $body) = $this->_driver->fetchComplete(
-            $this->_getFolder(), $this->_getBackendId()
+        list($headers, $body) = $this->_getDriver()->fetchComplete(
+            $this->_getFolder(), $this->getBackendId()
         );
         $mime_id = Horde_Kolab_Storage_Object_MimeType::matchMimePartToObjectType(
             $body, $this->getType()
@@ -408,26 +424,54 @@ class Horde_Kolab_Storage_Object implements ArrayAccess, Serializable
                 sprintf(
                     'Missing expected mime type (%s) in object "%s" in folder "%s"!',
                     Horde_Kolab_Storage_Object_MimeType::getMimeTypeFromObjectType($this->getType()),
-                    $this->_getBackendId(),
+                    $this->getBackendId(),
                     $this->_getFolder()
                 )
             );
         }
+
+        // Replace Kolab part.
         $original = $body->getPart($mime_id);
         $original->setContents(
-            $this->_driver->fetchBodypart($this->_getFolder(), $this->_getBackendId(), $mime_id)
+            $this->_getDriver()->fetchBodypart(
+                $this->_getFolder(),
+                $this->getBackendId(),
+                $mime_id
+            )
         );
         $this->_content = $original->getContents(array('stream' => true));
-
         $body->alterPart($mime_id, $this->createFreshKolabPart($data->save($this)));
         $body->buildMimeIds();
+
+        // Update attachments.
+        if (isset($this['_attachments'])) {
+            foreach ($this['_attachments'] as $name => $attachment) {
+                foreach ($body->getParts() as $part) {
+                    if ($part->getName() === $name) {
+                        $body->removePart($part->getMimeId());
+                        break;
+                    }
+                }
+                if (!is_null($attachment)) {
+                    $part = new Horde_Mime_Part();
+                    $part->setType($attachment['type']);
+                    $part->setContents($attachment['content']);
+                    $part->setName($name);
+                    $body->addPart($part);
+                }
+                $body->buildMimeIds();
+            }
+        }
+
         $this->_mime_part_id = Horde_Kolab_Storage_Object_MimeType::matchMimePartToObjectType(
             $body, $this->getType()
         );
-        $old_uid = $this->_getBackendId();
+        $old_uid = $this->getBackendId();
+
+        // Save message.
         $result = $this->_appendMessage($body, $headers);
-        $this->_driver->deleteMessages($this->_getFolder(), array($old_uid));
-        $this->_driver->expunge($this->_getFolder());
+        $this->_getDriver()->deleteMessages($this->_getFolder(), array($old_uid));
+        $this->_getDriver()->expunge($this->_getFolder());
         return $result;
     }
 
