@@ -15,7 +15,7 @@
 /**
  * Tests the Kolab mime message parser.
  *
- * Copyright 2012-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -43,7 +43,7 @@ extends PHPUnit_Framework_TestCase
     {
         $data = $this->getMock('Horde_Kolab_Storage_Object_Writer');
         $object = new Horde_Kolab_Storage_Object();
-        $object->load('1', $this->folder, $data, new stdClass);
+        $object->load('1', $this->folder, $data, new Horde_Mime_Part());
     }
 
     public function testObjectType()
